fax

# XMLRésuméLibrary: User Guide

employer | Element Reference | firstname

## Name

fax — A fax telephone number

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
location | Enumeration:
`home`
`work`
| None
targets | CDATA | None

## Description

The `fax` element contains a telephone number that can be used to connect to a facsimile machine. The phone number is not required to be in a specific format. (See `phone` for examples of numbers.)

### Parents

`fax` may be contained in these elements: `contact`

### Attributes

`location`

  Indicates the location that the phone number connects to. This attribute is optional.

## See Also

`email`, `pager`, `phone`.

## Examples

    <fax>555-555-1212</fax>

    <fax location="work">(123) 456-7890</fax>

    <fax location="home">345.324.2721</fax>

employer | Element Reference | firstname